export const SAMPLE_DEFAULT = {
    sampleRate: 25,
    sampleIntervalSeconds: 1,
};
export class TokenBucket {
    sampleRate;
    tokens;
    sampleIntervalSeconds;
    lastRefill;
    constructor(sampleRate, sampleIntervalSeconds) {
        this.sampleRate = sampleRate ?? SAMPLE_DEFAULT.sampleRate;
        this.sampleIntervalSeconds =
            (sampleIntervalSeconds ?? SAMPLE_DEFAULT.sampleIntervalSeconds) / 1000;
        this.lastRefill = Math.floor(Date.now() / 1000);
        this.tokens = this.sampleRate;
    }
    refill() {
        const now = Math.floor(Date.now() / 1000);
        const rate = (now - this.lastRefill) / this.sampleIntervalSeconds;
        this.tokens = Math.min(this.sampleRate, this.tokens + Math.floor(rate * this.sampleRate));
        this.lastRefill = now;
    }
    consume() {
        this.refill();
        if (this.tokens > 0) {
            this.tokens -= 1;
            return true;
        }
        return false;
    }
}
//# sourceMappingURL=tokenBucket.js.map